package it.eng.test.hibernate.persistentobject;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Transient;

@Entity
@Table(name = "testtable")
@NamedQueries(value = {
		@NamedQuery(name = "getItem", query = "select i from PersistentObject i where i.column1 = ?"),
		@NamedQuery(name = "getItems", query = "select i from PersistentObject i"),
		@NamedQuery(name = "deleteItem", query = "delete from PersistentObject i where i.column2 = ?")
		})
public class PersistentObject implements Serializable{		
		private static final long serialVersionUID = -2853745324178701257L;
		/*Required for Hibernate*/
		@Id
		@GeneratedValue(strategy = GenerationType.AUTO)
		@Column(name = "id")
		private Long id;
		/*Our columns*/
		@Column(name = "column1")
		private String column1;
		@Column(name = "column2")
		private int column2;
		/*This field is part of our PersistentObject but will not be stored on the DB*/
		@Transient
		private Object nonPersistent;
		
		/*Getters & Setters, every persistent field must have one for Hibernate*/
		public Long getID(){
			return id;
		}
		
		public String getColumn1() {
			return column1;
		}

		public void setColumn1(String column1) {
			this.column1 = column1;
		}

		public int getColumn2() {
			return column2;
		}

		public void setColumn2(int column2) {
			this.column2 = column2;
		}

		public void setId(Long id) {
			this.id = id;
		}
		
		public Object getNonPersistent() {
			return nonPersistent;
		}

		public void setNonPersistent(Object nonPersistent) {
			this.nonPersistent = nonPersistent;
		}
		
		/*Required for Hibernate*/
		public PersistentObject(){
		}
		
		/*Our own constructor*/
		public PersistentObject(String column1, int column2, Object nonPersistent){
			this.column1 = column1;
			this.column2 = column2;
			this.nonPersistent = nonPersistent;
		}
}
