package it.eng.test.hibernate.persistentobject;

import java.util.List;

import it.eng.test.hibernate.HibernateServiceUtil;

import javax.persistence.EntityManager;
import javax.persistence.Query;

public class PersistentObjectHibernateUtil {

	private static EntityManager entityManager;

	public static void initPersistentObjectHibernateUtil() {
		entityManager = HibernateServiceUtil.initEntityManager();
	}

	/*Create and store our object on the DB*/
	public static PersistentObject savePersistentObject(String column1, int column2, Object nonPersistent) {
		entityManager.getTransaction().begin();
		PersistentObject p = new PersistentObject();
		p.setColumn1(column1);
		p.setColumn2(column2);
		p.setNonPersistent(nonPersistent);
		entityManager.persist(p);
		entityManager.getTransaction().commit();
		return p;
	}
	
	/*Store an already existing object on the DB*/
	public static void savePersistentObject(PersistentObject p) {
		entityManager.getTransaction().begin();
		entityManager.persist(p);
		entityManager.getTransaction().commit();
	}

	/*Implementation of our NamedQueries*/
	
	public static PersistentObject getItem(String column1){
		try{
			Query query = entityManager.createNamedQuery("getItem");
			/*place this value where the first ? appeared in the query*/
			query.setParameter(1, column1);
			PersistentObject result = (PersistentObject) query.getSingleResult();
			return result;
		}catch(Exception e){
			System.err.println("unable to get PersistentObject "+column1+" from DB");
			return null;
		}
	}
	
	@SuppressWarnings("unchecked")
	public static List<PersistentObject> getItems(){
		try{
			Query query = entityManager.createNamedQuery("getItems");
			return query.getResultList();
		}catch(Exception e){
			System.err.println("unable to get PersistentObjects from DB");
			return null;
		}
	}
	
	public static void deleteItem(int column2){
		try{
			Query query = entityManager.createNamedQuery("deleteItem");
			/*place this value where the first ? appeared in the query*/
			query.setParameter(1, column2);
			query.executeUpdate();
		}catch(Exception e){
			System.err.println("unable to delete PersistentObject "+column2+" from DB "+e.getMessage());
			e.printStackTrace();
		}
	}
	
	/*We can also overload those methods*/
	public static void deleteItem(PersistentObject p){
		try{
			entityManager.getTransaction().begin();
			Query query = entityManager.createNamedQuery("deleteItem");
			query.setParameter(1, p.getColumn2());
			query.executeUpdate();
			entityManager.getTransaction().commit();
		}catch(Exception e){
			System.err.println("unable to delete PersistentObject "+p.getColumn2()+" from DB "+e.getMessage());
			e.printStackTrace();
		}
	}
	
	/*Updates an object already stored*/
	public static void updatePersistentObject(PersistentObject p){
		try{
			if (p == null){
				System.err.println("cannot update PersistentObject because it is NULL");
				return;
			}
			entityManager.getTransaction().begin();
			entityManager.merge(p);
			entityManager.getTransaction().commit();
		}catch(Exception e){
			System.err.println("unable to update PersistentObject "+p.getColumn1()+" on DB");
		}
	}

}
